@@ -9,7 +9,7 @@ def determine_operating_system():
     system = platform.system()
     bits = platform.architecture()[0]
     if system == "Windows":
-        return consts.OperatingSystem.Windows
+        return consts.OperatingSystem.WINDOWS
     elif system == "Linux":
         if bits.startswith("64"):
             return consts.OperatingSystem.LINUX_64
